@@ -19,6 +19,8 @@
 #ifndef GDM_MISC_H
 #define GDM_MISC_H
 
+#include <sys/types.h>
+
 #include "config.h"
 #include "gdm.h"
 
@@ -35,7 +37,8 @@ int gdm_get_free_display (int start, uid_t server_uid);
 
 gboolean gdm_text_message_dialog (const char *msg);
 gboolean gdm_text_yesno_dialog (const char *msg, gboolean *ret);
-int	gdm_exec_wait (char * const *argv, gboolean no_display);
+int	gdm_exec_wait (char * const *argv, gboolean no_display,
+		       gboolean de_setuid);
 
 /* done before each login.  This can do so sanity ensuring,
  * one of the things it does now is make sure /tmp/.ICE-unix
@@ -55,6 +58,8 @@ const GList * gdm_peek_local_address_list (void);
 gboolean gdm_is_local_addr (struct in_addr *ia);
 gboolean gdm_is_loopback_addr (struct in_addr *ia);
 
+gboolean gdm_setup_gids (const char *login, gid_t gid);
+
 #endif /* GDM_MISC_H */
 
 /* EOF */
